Learn R Programming

pedigree (version 1.4)

pedigree-package: Package to deal with pedigree data

Description

Package with functions to analyse and transform pedigree data. A pedigree is a data.frame where the first column contains an ID, and the second and third columns contain ID of first and second parent.

Arguments

See Also

trimPed orderPed countGen makeA makeAinv calcInbreeding add.Inds